@@ -54,7 +54,7 @@
 #
 # These variables control the setup
 #
-set addrVersion {$Revision: 1.15 $}
+set addrVersion {$Revision: 1.16 $}
 
 # Addr_debug, if ==1, enables printing messages while this stuff runs.
 # Set Addr_debug 1 in your user.tcl before invoking Addr_Init to enable debug messages
@@ -693,7 +693,7 @@ proc LDAP_Lookup {n} {
     
     Exmh_Status "Querying $addr_db(ldap_server) from $addr_db(ldap_searchbase) with $n via $addr_db(ldap_searchprog)..."
 
-    set query "(|(cn=*$n*)(mail=*$n*)(sn=*$n*)(givenname=*$n*))"
+    set query "\"(|(cn=*$n*)(mail=*$n*)(sn=*$n*)(givenname=*$n*))\""
     if {[catch {set query "[encoding convertto $addr_db(ldap_encoding) "$query"]"} err]} {
 	Exmh_Debug "LDAP_Lookup encoding convertto: $err"
     }
