@@ -394,6 +394,7 @@ proc Mh_SetCur { folder msgid } {
 	($mhPriv(cur,$folder) == $msgid)} {
 	return
     }
+    Mh_SequenceUpdate $folder replace cur $msgid
     Seq_Set $folder cur $msgid
     set mhPriv(cur,$folder) $msgid
 }
@@ -516,7 +517,6 @@ proc MhReadSeqs {folder seqsvar} {
 
 proc MhGetSeqCache {folder seq } {
     global mhPriv
-    Exmh_Debug "MhGetSeqCache $folder $seq"
     set seqlist ""
     if {[info exists mhPriv(pubseq,$folder,$seq)]} {
         set seqlist $mhPriv(pubseq,$folder,$seq)
@@ -546,6 +546,10 @@ proc MhSeqExpand { folder sequence } {
     set seq {}
     set rseq {}
     foreach range [split [string trim $sequence]] {
+	if ![regexp {^[0-9]+(-[0-9]+)?$} $range] {
+	    # just ignore anything bogus
+	    continue;
+	}
 	set parts [split [string trim $range] -]
 	if {[llength $parts] == 1} {
 	    lappend seq $parts
@@ -620,11 +624,11 @@ proc Mh_SequenceUpdate { folder how seq {msgids {}} {which public}} {
 		if {$mhPriv(mode,$thisseq) == "public"} {
 		    if {![regexp {^ *$} $seqs($thisseq)]} {
 			if [regexp -- {-} $seqs($thisseq)] {
-			    set seq $seqs($thisseq)
+			    set realseq $seqs($thisseq)
 			} else {
-			    set seq [MhSeqMake $seqs($thisseq)]
+			    set realseq [MhSeqMake $seqs($thisseq)]
 			}
-			puts $out "$thisseq: $seq"
+			puts $out "$thisseq: $realseq"
 		    }
 		}
 	    }
@@ -649,11 +653,11 @@ proc Mh_SequenceUpdate { folder how seq {msgids {}} {which public}} {
 		if {[string compare $mhPriv(mode,$thisseq) "private"] == 0} {
 		    if {![regexp {^ *$} $seqs($thisseq)]} {
 			if [regexp -- {-} $seqs($thisseq)] {
-			    set seq $seqs($thisseq)
+			    set realseq $seqs($thisseq)
 			} else {
-			    set seq [MhSeqMake $seqs($thisseq)]
+			    set realseq [MhSeqMake $seqs($thisseq)]
 			}
-			puts $out "atr-$thisseq-$mhProfile(path)/$folder: $seq"
+			puts $out "atr-$thisseq-$mhProfile(path)/$folder: $realseq"
 		    }
 		}
 	    }
@@ -1213,6 +1217,12 @@ proc Mh_FindFile { filename } {
 }
 # exmh-2.5 APIs
 # Mh_ClearCur 
-# Mh_MarkSeen
-# Mh_MarkUnseen
 # Mh_Unseen 
+
+proc Mh_MarkSeen {folder ids} {
+    global mhProfile
+    Seq_Del $folder $mhProfile(unseen-sequence) $ids
+}
+proc Mh_MarkUnseen {folder ids} {
+    Seq_Add $folder $mhProfile(unseen-sequence) $ids
+}
